==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/kasten/controllers/view/poddecoder/types/hexadecimal8.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef HEXADECIMAL8_H
#define HEXADECIMAL8_H

// Qt
#include <QMetaType>
#include <QString>

struct Hexadecimal8
{
public:
    Hexadecimal8(quint8 v);
    Hexadecimal8();

public:
    QString toString() const;

public:
    quint8 value = 0;
};

inline Hexadecimal8::Hexadecimal8() = default;
inline Hexadecimal8::Hexadecimal8(quint8 v) : value(v) {}

inline QString Hexadecimal8::toString() const
{
    return QStringLiteral("%1").arg(value, 2, 16, QChar::fromLatin1('0'));
}

Q_DECLARE_METATYPE(Hexadecimal8)

#endif

==> okteta-4.14.3.tar.xz: okteta-4.14.3/kasten/controllers/view/poddecoder/types/hexadecimal8.h <==
/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef HEXADECIMAL8_H
#define HEXADECIMAL8_H

// Qt
#include <QtCore/QMetaType>
#include <QtCore/QString>


struct Hexadecimal8
{
  public:
    Hexadecimal8( quint8 v );
    Hexadecimal8();

  public:
    QString toString() const;

  public:
    quint8 value;
};


inline Hexadecimal8::Hexadecimal8() : value( 0 ) {}
inline Hexadecimal8::Hexadecimal8( quint8 v ) : value( v ) {}

inline QString Hexadecimal8::toString() const
{
    return QString::fromLatin1( "%1" ).arg( value, 2, 16, QChar::fromLatin1('0') );
}

Q_DECLARE_METATYPE( Hexadecimal8 )

#endif
